# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kademlia.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import node_pb2 as node__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kademlia.proto',
  package='io.casperlabs.comm.discovery',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0ekademlia.proto\x12\x1cio.casperlabs.comm.discovery\x1a\nnode.proto\"A\n\x0bPingRequest\x12\x32\n\x06sender\x18\x01 \x01(\x0b\x32\".io.casperlabs.comm.discovery.Node\"\x0e\n\x0cPingResponse\"O\n\rLookupRequest\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x32\n\x06sender\x18\x02 \x01(\x0b\x32\".io.casperlabs.comm.discovery.Node\"C\n\x0eLookupResponse\x12\x31\n\x05nodes\x18\x01 \x03(\x0b\x32\".io.casperlabs.comm.discovery.Node2\xd9\x01\n\x0fKademliaService\x12_\n\x04Ping\x12).io.casperlabs.comm.discovery.PingRequest\x1a*.io.casperlabs.comm.discovery.PingResponse\"\x00\x12\x65\n\x06Lookup\x12+.io.casperlabs.comm.discovery.LookupRequest\x1a,.io.casperlabs.comm.discovery.LookupResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[node__pb2.DESCRIPTOR,])




_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='io.casperlabs.comm.discovery.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='io.casperlabs.comm.discovery.PingRequest.sender', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=125,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='io.casperlabs.comm.discovery.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=141,
)


_LOOKUPREQUEST = _descriptor.Descriptor(
  name='LookupRequest',
  full_name='io.casperlabs.comm.discovery.LookupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='io.casperlabs.comm.discovery.LookupRequest.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='io.casperlabs.comm.discovery.LookupRequest.sender', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=222,
)


_LOOKUPRESPONSE = _descriptor.Descriptor(
  name='LookupResponse',
  full_name='io.casperlabs.comm.discovery.LookupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='io.casperlabs.comm.discovery.LookupResponse.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=291,
)

_PINGREQUEST.fields_by_name['sender'].message_type = node__pb2._NODE
_LOOKUPREQUEST.fields_by_name['sender'].message_type = node__pb2._NODE
_LOOKUPRESPONSE.fields_by_name['nodes'].message_type = node__pb2._NODE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['LookupRequest'] = _LOOKUPREQUEST
DESCRIPTOR.message_types_by_name['LookupResponse'] = _LOOKUPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'kademlia_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.discovery.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'kademlia_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.discovery.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

LookupRequest = _reflection.GeneratedProtocolMessageType('LookupRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPREQUEST,
  '__module__' : 'kademlia_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.discovery.LookupRequest)
  })
_sym_db.RegisterMessage(LookupRequest)

LookupResponse = _reflection.GeneratedProtocolMessageType('LookupResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPRESPONSE,
  '__module__' : 'kademlia_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.discovery.LookupResponse)
  })
_sym_db.RegisterMessage(LookupResponse)



_KADEMLIASERVICE = _descriptor.ServiceDescriptor(
  name='KademliaService',
  full_name='io.casperlabs.comm.discovery.KademliaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=294,
  serialized_end=511,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='io.casperlabs.comm.discovery.KademliaService.Ping',
    index=0,
    containing_service=None,
    input_type=_PINGREQUEST,
    output_type=_PINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Lookup',
    full_name='io.casperlabs.comm.discovery.KademliaService.Lookup',
    index=1,
    containing_service=None,
    input_type=_LOOKUPREQUEST,
    output_type=_LOOKUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KADEMLIASERVICE)

DESCRIPTOR.services_by_name['KademliaService'] = _KADEMLIASERVICE

# @@protoc_insertion_point(module_scope)
