# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transforms.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import state_pb2 as state__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='transforms.proto',
  package='io.casperlabs.ipc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10transforms.proto\x12\x11io.casperlabs.ipc\x1a\x0bstate.proto\"/\n\x0cTypeMismatch\x12\x10\n\x08\x65xpected\x18\x01 \x01(\t\x12\r\n\x05\x66ound\x18\x02 \x01(\t\"\xb1\x03\n\tTransform\x12\x38\n\x08identity\x18\x01 \x01(\x0b\x32$.io.casperlabs.ipc.TransformIdentityH\x00\x12\x37\n\x07\x61\x64\x64_i32\x18\x02 \x01(\x0b\x32$.io.casperlabs.ipc.TransformAddInt32H\x00\x12\x38\n\x07\x61\x64\x64_u64\x18\x03 \x01(\x0b\x32%.io.casperlabs.ipc.TransformAddUInt64H\x00\x12\x32\n\x05write\x18\x04 \x01(\x0b\x32!.io.casperlabs.ipc.TransformWriteH\x00\x12\x37\n\x08\x61\x64\x64_keys\x18\x05 \x01(\x0b\x32#.io.casperlabs.ipc.TransformAddKeysH\x00\x12\x36\n\x07\x66\x61ilure\x18\x06 \x01(\x0b\x32#.io.casperlabs.ipc.TransformFailureH\x00\x12<\n\x0b\x61\x64\x64_big_int\x18\x07 \x01(\x0b\x32%.io.casperlabs.ipc.TransformAddBigIntH\x00\x42\x14\n\x12transform_instance\"\x13\n\x11TransformIdentity\"\"\n\x11TransformAddInt32\x12\r\n\x05value\x18\x01 \x01(\x05\"#\n\x12TransformAddUInt64\x12\r\n\x05value\x18\x01 \x01(\x04\"Q\n\x12TransformAddBigInt\x12;\n\x05value\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\"Q\n\x10TransformAddKeys\x12=\n\x05value\x18\x01 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKey\"R\n\x0eTransformWrite\x12@\n\x05value\x18\x01 \x01(\x0b\x32\x31.io.casperlabs.casper.consensus.state.StoredValue\"`\n\x10TransformFailure\x12\x38\n\rtype_mismatch\x18\x01 \x01(\x0b\x32\x1f.io.casperlabs.ipc.TypeMismatchH\x00\x42\x12\n\x10\x66\x61ilure_instance\"y\n\x0eTransformEntry\x12\x36\n\x03key\x18\x01 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.Key\x12/\n\ttransform\x18\x02 \x01(\x0b\x32\x1c.io.casperlabs.ipc.Transformb\x06proto3'
  ,
  dependencies=[state__pb2.DESCRIPTOR,])




_TYPEMISMATCH = _descriptor.Descriptor(
  name='TypeMismatch',
  full_name='io.casperlabs.ipc.TypeMismatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected', full_name='io.casperlabs.ipc.TypeMismatch.expected', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='found', full_name='io.casperlabs.ipc.TypeMismatch.found', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=99,
)


_TRANSFORM = _descriptor.Descriptor(
  name='Transform',
  full_name='io.casperlabs.ipc.Transform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='io.casperlabs.ipc.Transform.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_i32', full_name='io.casperlabs.ipc.Transform.add_i32', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_u64', full_name='io.casperlabs.ipc.Transform.add_u64', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write', full_name='io.casperlabs.ipc.Transform.write', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_keys', full_name='io.casperlabs.ipc.Transform.add_keys', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='io.casperlabs.ipc.Transform.failure', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_big_int', full_name='io.casperlabs.ipc.Transform.add_big_int', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='transform_instance', full_name='io.casperlabs.ipc.Transform.transform_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102,
  serialized_end=535,
)


_TRANSFORMIDENTITY = _descriptor.Descriptor(
  name='TransformIdentity',
  full_name='io.casperlabs.ipc.TransformIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=556,
)


_TRANSFORMADDINT32 = _descriptor.Descriptor(
  name='TransformAddInt32',
  full_name='io.casperlabs.ipc.TransformAddInt32',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.TransformAddInt32.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=592,
)


_TRANSFORMADDUINT64 = _descriptor.Descriptor(
  name='TransformAddUInt64',
  full_name='io.casperlabs.ipc.TransformAddUInt64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.TransformAddUInt64.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=629,
)


_TRANSFORMADDBIGINT = _descriptor.Descriptor(
  name='TransformAddBigInt',
  full_name='io.casperlabs.ipc.TransformAddBigInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.TransformAddBigInt.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=712,
)


_TRANSFORMADDKEYS = _descriptor.Descriptor(
  name='TransformAddKeys',
  full_name='io.casperlabs.ipc.TransformAddKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.TransformAddKeys.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=795,
)


_TRANSFORMWRITE = _descriptor.Descriptor(
  name='TransformWrite',
  full_name='io.casperlabs.ipc.TransformWrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.TransformWrite.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=879,
)


_TRANSFORMFAILURE = _descriptor.Descriptor(
  name='TransformFailure',
  full_name='io.casperlabs.ipc.TransformFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_mismatch', full_name='io.casperlabs.ipc.TransformFailure.type_mismatch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='failure_instance', full_name='io.casperlabs.ipc.TransformFailure.failure_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=881,
  serialized_end=977,
)


_TRANSFORMENTRY = _descriptor.Descriptor(
  name='TransformEntry',
  full_name='io.casperlabs.ipc.TransformEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.ipc.TransformEntry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform', full_name='io.casperlabs.ipc.TransformEntry.transform', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1100,
)

_TRANSFORM.fields_by_name['identity'].message_type = _TRANSFORMIDENTITY
_TRANSFORM.fields_by_name['add_i32'].message_type = _TRANSFORMADDINT32
_TRANSFORM.fields_by_name['add_u64'].message_type = _TRANSFORMADDUINT64
_TRANSFORM.fields_by_name['write'].message_type = _TRANSFORMWRITE
_TRANSFORM.fields_by_name['add_keys'].message_type = _TRANSFORMADDKEYS
_TRANSFORM.fields_by_name['failure'].message_type = _TRANSFORMFAILURE
_TRANSFORM.fields_by_name['add_big_int'].message_type = _TRANSFORMADDBIGINT
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['identity'])
_TRANSFORM.fields_by_name['identity'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['add_i32'])
_TRANSFORM.fields_by_name['add_i32'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['add_u64'])
_TRANSFORM.fields_by_name['add_u64'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['write'])
_TRANSFORM.fields_by_name['write'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['add_keys'])
_TRANSFORM.fields_by_name['add_keys'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['failure'])
_TRANSFORM.fields_by_name['failure'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORM.oneofs_by_name['transform_instance'].fields.append(
  _TRANSFORM.fields_by_name['add_big_int'])
_TRANSFORM.fields_by_name['add_big_int'].containing_oneof = _TRANSFORM.oneofs_by_name['transform_instance']
_TRANSFORMADDBIGINT.fields_by_name['value'].message_type = state__pb2._BIGINT
_TRANSFORMADDKEYS.fields_by_name['value'].message_type = state__pb2._NAMEDKEY
_TRANSFORMWRITE.fields_by_name['value'].message_type = state__pb2._STOREDVALUE
_TRANSFORMFAILURE.fields_by_name['type_mismatch'].message_type = _TYPEMISMATCH
_TRANSFORMFAILURE.oneofs_by_name['failure_instance'].fields.append(
  _TRANSFORMFAILURE.fields_by_name['type_mismatch'])
_TRANSFORMFAILURE.fields_by_name['type_mismatch'].containing_oneof = _TRANSFORMFAILURE.oneofs_by_name['failure_instance']
_TRANSFORMENTRY.fields_by_name['key'].message_type = state__pb2._KEY
_TRANSFORMENTRY.fields_by_name['transform'].message_type = _TRANSFORM
DESCRIPTOR.message_types_by_name['TypeMismatch'] = _TYPEMISMATCH
DESCRIPTOR.message_types_by_name['Transform'] = _TRANSFORM
DESCRIPTOR.message_types_by_name['TransformIdentity'] = _TRANSFORMIDENTITY
DESCRIPTOR.message_types_by_name['TransformAddInt32'] = _TRANSFORMADDINT32
DESCRIPTOR.message_types_by_name['TransformAddUInt64'] = _TRANSFORMADDUINT64
DESCRIPTOR.message_types_by_name['TransformAddBigInt'] = _TRANSFORMADDBIGINT
DESCRIPTOR.message_types_by_name['TransformAddKeys'] = _TRANSFORMADDKEYS
DESCRIPTOR.message_types_by_name['TransformWrite'] = _TRANSFORMWRITE
DESCRIPTOR.message_types_by_name['TransformFailure'] = _TRANSFORMFAILURE
DESCRIPTOR.message_types_by_name['TransformEntry'] = _TRANSFORMENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TypeMismatch = _reflection.GeneratedProtocolMessageType('TypeMismatch', (_message.Message,), {
  'DESCRIPTOR' : _TYPEMISMATCH,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TypeMismatch)
  })
_sym_db.RegisterMessage(TypeMismatch)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.Transform)
  })
_sym_db.RegisterMessage(Transform)

TransformIdentity = _reflection.GeneratedProtocolMessageType('TransformIdentity', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMIDENTITY,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformIdentity)
  })
_sym_db.RegisterMessage(TransformIdentity)

TransformAddInt32 = _reflection.GeneratedProtocolMessageType('TransformAddInt32', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMADDINT32,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformAddInt32)
  })
_sym_db.RegisterMessage(TransformAddInt32)

TransformAddUInt64 = _reflection.GeneratedProtocolMessageType('TransformAddUInt64', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMADDUINT64,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformAddUInt64)
  })
_sym_db.RegisterMessage(TransformAddUInt64)

TransformAddBigInt = _reflection.GeneratedProtocolMessageType('TransformAddBigInt', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMADDBIGINT,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformAddBigInt)
  })
_sym_db.RegisterMessage(TransformAddBigInt)

TransformAddKeys = _reflection.GeneratedProtocolMessageType('TransformAddKeys', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMADDKEYS,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformAddKeys)
  })
_sym_db.RegisterMessage(TransformAddKeys)

TransformWrite = _reflection.GeneratedProtocolMessageType('TransformWrite', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMWRITE,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformWrite)
  })
_sym_db.RegisterMessage(TransformWrite)

TransformFailure = _reflection.GeneratedProtocolMessageType('TransformFailure', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMFAILURE,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformFailure)
  })
_sym_db.RegisterMessage(TransformFailure)

TransformEntry = _reflection.GeneratedProtocolMessageType('TransformEntry', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMENTRY,
  '__module__' : 'transforms_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.TransformEntry)
  })
_sym_db.RegisterMessage(TransformEntry)


# @@protoc_insertion_point(module_scope)
