# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: info.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import consensus_pb2 as consensus__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='info.proto',
  package='io.casperlabs.casper.consensus.info',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\ninfo.proto\x12#io.casperlabs.casper.consensus.info\x1a\x0f\x63onsensus.proto\"\xa9\x04\n\tBlockInfo\x12=\n\x07summary\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.BlockSummary\x12\x45\n\x06status\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.info.BlockInfo.Status\x1a\xf8\x02\n\x06Status\x12J\n\x05stats\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats\x12\x14\n\x0c\x63hild_hashes\x18\x03 \x03(\x0c\x12P\n\x08\x66inality\x18\x05 \x01(\x0e\x32>.io.casperlabs.casper.consensus.info.BlockInfo.Status.Finality\x1av\n\x05Stats\x12\x18\n\x10\x62lock_size_bytes\x18\x01 \x01(\r\x12\x1a\n\x12\x64\x65ploy_error_count\x18\x02 \x01(\r\x12\x19\n\x11\x64\x65ploy_cost_total\x18\x03 \x01(\x04\x12\x1c\n\x14\x64\x65ploy_gas_price_avg\x18\x04 \x01(\x04\"6\n\x08\x46inality\x12\r\n\tUNDECIDED\x10\x00\x12\r\n\tFINALIZED\x10\x01\x12\x0c\n\x08ORPHANED\x10\x02J\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\x1b\n\x04View\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"\xd9\x04\n\nDeployInfo\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x12\\\n\x12processing_results\x18\x02 \x03(\x0b\x32@.io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.info.DeployInfo.Status\x1a\x9c\x01\n\x10ProcessingResult\x12\x42\n\nblock_info\x18\x01 \x01(\x0b\x32..io.casperlabs.casper.consensus.info.BlockInfo\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x04\x12\x10\n\x08is_error\x18\x03 \x01(\x08\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\r\x1a_\n\x06Status\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.io.casperlabs.casper.consensus.info.DeployInfo.State\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1b\n\x04View\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"P\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tPROCESSED\x10\x02\x12\r\n\tFINALIZED\x10\x03\x12\r\n\tDISCARDED\x10\x04\"\xe5\x0b\n\x05\x45vent\x12\x10\n\x08\x65vent_id\x18\t \x01(\x04\x12L\n\x0b\x62lock_added\x18\x01 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.info.Event.BlockAddedH\x00\x12[\n\x13new_finalized_block\x18\x02 \x01(\x0b\x32<.io.casperlabs.casper.consensus.info.Event.NewFinalizedBlockH\x00\x12N\n\x0c\x64\x65ploy_added\x18\x03 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.info.Event.DeployAddedH\x00\x12T\n\x0f\x64\x65ploy_requeued\x18\x04 \x01(\x0b\x32\x39.io.casperlabs.casper.consensus.info.Event.DeployRequeuedH\x00\x12V\n\x10\x64\x65ploy_discarded\x18\x05 \x01(\x0b\x32:.io.casperlabs.casper.consensus.info.Event.DeployDiscardedH\x00\x12V\n\x10\x64\x65ploy_processed\x18\x06 \x01(\x0b\x32:.io.casperlabs.casper.consensus.info.Event.DeployProcessedH\x00\x12V\n\x10\x64\x65ploy_finalized\x18\x07 \x01(\x0b\x32:.io.casperlabs.casper.consensus.info.Event.DeployFinalizedH\x00\x12T\n\x0f\x64\x65ploy_orphaned\x18\x08 \x01(\x0b\x32\x39.io.casperlabs.casper.consensus.info.Event.DeployOrphanedH\x00\x1aK\n\nBlockAdded\x12=\n\x05\x62lock\x18\x01 \x01(\x0b\x32..io.casperlabs.casper.consensus.info.BlockInfo\x1a|\n\x11NewFinalizedBlock\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12)\n!indirectly_finalized_block_hashes\x18\x02 \x03(\x0c\x12(\n indirectly_orphaned_block_hashes\x18\x03 \x03(\x0c\x1a\x45\n\x0b\x44\x65ployAdded\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x1aZ\n\x0f\x44\x65ployDiscarded\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x12\x0f\n\x07message\x18\x02 \x01(\t\x1aH\n\x0e\x44\x65ployRequeued\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x1av\n\x0f\x44\x65ployProcessed\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12O\n\x10processed_deploy\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.Block.ProcessedDeploy\x1av\n\x0f\x44\x65ployFinalized\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12O\n\x10processed_deploy\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.Block.ProcessedDeploy\x1aj\n\x0e\x44\x65ployOrphaned\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12\x44\n\x0b\x64\x65ploy_info\x18\x02 \x01(\x0b\x32/.io.casperlabs.casper.consensus.info.DeployInfoB\x07\n\x05valueb\x06proto3'
  ,
  dependencies=[consensus__pb2.DESCRIPTOR,])



_BLOCKINFO_STATUS_FINALITY = _descriptor.EnumDescriptor(
  name='Finality',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Finality',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDECIDED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINALIZED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORPHANED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=527,
  serialized_end=581,
)
_sym_db.RegisterEnumDescriptor(_BLOCKINFO_STATUS_FINALITY)

_BLOCKINFO_VIEW = _descriptor.EnumDescriptor(
  name='View',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.View',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=595,
  serialized_end=622,
)
_sym_db.RegisterEnumDescriptor(_BLOCKINFO_VIEW)

_DEPLOYINFO_VIEW = _descriptor.EnumDescriptor(
  name='View',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.View',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=595,
  serialized_end=622,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYINFO_VIEW)

_DEPLOYINFO_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINALIZED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCARDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1146,
  serialized_end=1226,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYINFO_STATE)


_BLOCKINFO_STATUS_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_size_bytes', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.block_size_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_error_count', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.deploy_error_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_cost_total', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.deploy_cost_total', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_gas_price_avg', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.deploy_gas_price_avg', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=525,
)

_BLOCKINFO_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.stats', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_hashes', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.child_hashes', index=1,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finality', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.finality', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BLOCKINFO_STATUS_STATS, ],
  enum_types=[
    _BLOCKINFO_STATUS_FINALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=593,
)

_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='io.casperlabs.casper.consensus.info.BlockInfo.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='io.casperlabs.casper.consensus.info.BlockInfo.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BLOCKINFO_STATUS, ],
  enum_types=[
    _BLOCKINFO_VIEW,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=622,
)


_DEPLOYINFO_PROCESSINGRESULT = _descriptor.Descriptor(
  name='ProcessingResult',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_info', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.block_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.cost', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_error', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.is_error', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.error_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.stage', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=1018,
)

_DEPLOYINFO_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1115,
)

_DEPLOYINFO = _descriptor.Descriptor(
  name='DeployInfo',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.info.DeployInfo.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_results', full_name='io.casperlabs.casper.consensus.info.DeployInfo.processing_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='io.casperlabs.casper.consensus.info.DeployInfo.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYINFO_PROCESSINGRESULT, _DEPLOYINFO_STATUS, ],
  enum_types=[
    _DEPLOYINFO_VIEW,
    _DEPLOYINFO_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=1226,
)


_EVENT_BLOCKADDED = _descriptor.Descriptor(
  name='BlockAdded',
  full_name='io.casperlabs.casper.consensus.info.Event.BlockAdded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='io.casperlabs.casper.consensus.info.Event.BlockAdded.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1943,
  serialized_end=2018,
)

_EVENT_NEWFINALIZEDBLOCK = _descriptor.Descriptor(
  name='NewFinalizedBlock',
  full_name='io.casperlabs.casper.consensus.info.Event.NewFinalizedBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.info.Event.NewFinalizedBlock.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indirectly_finalized_block_hashes', full_name='io.casperlabs.casper.consensus.info.Event.NewFinalizedBlock.indirectly_finalized_block_hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indirectly_orphaned_block_hashes', full_name='io.casperlabs.casper.consensus.info.Event.NewFinalizedBlock.indirectly_orphaned_block_hashes', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2020,
  serialized_end=2144,
)

_EVENT_DEPLOYADDED = _descriptor.Descriptor(
  name='DeployAdded',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployAdded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.info.Event.DeployAdded.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2146,
  serialized_end=2215,
)

_EVENT_DEPLOYDISCARDED = _descriptor.Descriptor(
  name='DeployDiscarded',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployDiscarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.info.Event.DeployDiscarded.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.casper.consensus.info.Event.DeployDiscarded.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2307,
)

_EVENT_DEPLOYREQUEUED = _descriptor.Descriptor(
  name='DeployRequeued',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployRequeued',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.info.Event.DeployRequeued.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2309,
  serialized_end=2381,
)

_EVENT_DEPLOYPROCESSED = _descriptor.Descriptor(
  name='DeployProcessed',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployProcessed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.info.Event.DeployProcessed.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processed_deploy', full_name='io.casperlabs.casper.consensus.info.Event.DeployProcessed.processed_deploy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2501,
)

_EVENT_DEPLOYFINALIZED = _descriptor.Descriptor(
  name='DeployFinalized',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployFinalized',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.info.Event.DeployFinalized.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processed_deploy', full_name='io.casperlabs.casper.consensus.info.Event.DeployFinalized.processed_deploy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2503,
  serialized_end=2621,
)

_EVENT_DEPLOYORPHANED = _descriptor.Descriptor(
  name='DeployOrphaned',
  full_name='io.casperlabs.casper.consensus.info.Event.DeployOrphaned',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.info.Event.DeployOrphaned.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_info', full_name='io.casperlabs.casper.consensus.info.Event.DeployOrphaned.deploy_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2623,
  serialized_end=2729,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='io.casperlabs.casper.consensus.info.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='io.casperlabs.casper.consensus.info.Event.event_id', index=0,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_added', full_name='io.casperlabs.casper.consensus.info.Event.block_added', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_finalized_block', full_name='io.casperlabs.casper.consensus.info.Event.new_finalized_block', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_added', full_name='io.casperlabs.casper.consensus.info.Event.deploy_added', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_requeued', full_name='io.casperlabs.casper.consensus.info.Event.deploy_requeued', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_discarded', full_name='io.casperlabs.casper.consensus.info.Event.deploy_discarded', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_processed', full_name='io.casperlabs.casper.consensus.info.Event.deploy_processed', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_finalized', full_name='io.casperlabs.casper.consensus.info.Event.deploy_finalized', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_orphaned', full_name='io.casperlabs.casper.consensus.info.Event.deploy_orphaned', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_BLOCKADDED, _EVENT_NEWFINALIZEDBLOCK, _EVENT_DEPLOYADDED, _EVENT_DEPLOYDISCARDED, _EVENT_DEPLOYREQUEUED, _EVENT_DEPLOYPROCESSED, _EVENT_DEPLOYFINALIZED, _EVENT_DEPLOYORPHANED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.info.Event.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1229,
  serialized_end=2738,
)

_BLOCKINFO_STATUS_STATS.containing_type = _BLOCKINFO_STATUS
_BLOCKINFO_STATUS.fields_by_name['stats'].message_type = _BLOCKINFO_STATUS_STATS
_BLOCKINFO_STATUS.fields_by_name['finality'].enum_type = _BLOCKINFO_STATUS_FINALITY
_BLOCKINFO_STATUS.containing_type = _BLOCKINFO
_BLOCKINFO_STATUS_FINALITY.containing_type = _BLOCKINFO_STATUS
_BLOCKINFO.fields_by_name['summary'].message_type = consensus__pb2._BLOCKSUMMARY
_BLOCKINFO.fields_by_name['status'].message_type = _BLOCKINFO_STATUS
_BLOCKINFO_VIEW.containing_type = _BLOCKINFO
_DEPLOYINFO_PROCESSINGRESULT.fields_by_name['block_info'].message_type = _BLOCKINFO
_DEPLOYINFO_PROCESSINGRESULT.containing_type = _DEPLOYINFO
_DEPLOYINFO_STATUS.fields_by_name['state'].enum_type = _DEPLOYINFO_STATE
_DEPLOYINFO_STATUS.containing_type = _DEPLOYINFO
_DEPLOYINFO.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_DEPLOYINFO.fields_by_name['processing_results'].message_type = _DEPLOYINFO_PROCESSINGRESULT
_DEPLOYINFO.fields_by_name['status'].message_type = _DEPLOYINFO_STATUS
_DEPLOYINFO_VIEW.containing_type = _DEPLOYINFO
_DEPLOYINFO_STATE.containing_type = _DEPLOYINFO
_EVENT_BLOCKADDED.fields_by_name['block'].message_type = _BLOCKINFO
_EVENT_BLOCKADDED.containing_type = _EVENT
_EVENT_NEWFINALIZEDBLOCK.containing_type = _EVENT
_EVENT_DEPLOYADDED.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_EVENT_DEPLOYADDED.containing_type = _EVENT
_EVENT_DEPLOYDISCARDED.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_EVENT_DEPLOYDISCARDED.containing_type = _EVENT
_EVENT_DEPLOYREQUEUED.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_EVENT_DEPLOYREQUEUED.containing_type = _EVENT
_EVENT_DEPLOYPROCESSED.fields_by_name['processed_deploy'].message_type = consensus__pb2._BLOCK_PROCESSEDDEPLOY
_EVENT_DEPLOYPROCESSED.containing_type = _EVENT
_EVENT_DEPLOYFINALIZED.fields_by_name['processed_deploy'].message_type = consensus__pb2._BLOCK_PROCESSEDDEPLOY
_EVENT_DEPLOYFINALIZED.containing_type = _EVENT
_EVENT_DEPLOYORPHANED.fields_by_name['deploy_info'].message_type = _DEPLOYINFO
_EVENT_DEPLOYORPHANED.containing_type = _EVENT
_EVENT.fields_by_name['block_added'].message_type = _EVENT_BLOCKADDED
_EVENT.fields_by_name['new_finalized_block'].message_type = _EVENT_NEWFINALIZEDBLOCK
_EVENT.fields_by_name['deploy_added'].message_type = _EVENT_DEPLOYADDED
_EVENT.fields_by_name['deploy_requeued'].message_type = _EVENT_DEPLOYREQUEUED
_EVENT.fields_by_name['deploy_discarded'].message_type = _EVENT_DEPLOYDISCARDED
_EVENT.fields_by_name['deploy_processed'].message_type = _EVENT_DEPLOYPROCESSED
_EVENT.fields_by_name['deploy_finalized'].message_type = _EVENT_DEPLOYFINALIZED
_EVENT.fields_by_name['deploy_orphaned'].message_type = _EVENT_DEPLOYORPHANED
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['block_added'])
_EVENT.fields_by_name['block_added'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['new_finalized_block'])
_EVENT.fields_by_name['new_finalized_block'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_added'])
_EVENT.fields_by_name['deploy_added'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_requeued'])
_EVENT.fields_by_name['deploy_requeued'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_discarded'])
_EVENT.fields_by_name['deploy_discarded'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_processed'])
_EVENT.fields_by_name['deploy_processed'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_finalized'])
_EVENT.fields_by_name['deploy_finalized'].containing_oneof = _EVENT.oneofs_by_name['value']
_EVENT.oneofs_by_name['value'].fields.append(
  _EVENT.fields_by_name['deploy_orphaned'])
_EVENT.fields_by_name['deploy_orphaned'].containing_oneof = _EVENT.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['DeployInfo'] = _DEPLOYINFO
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), {

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {

    'Stats' : _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
      'DESCRIPTOR' : _BLOCKINFO_STATUS_STATS,
      '__module__' : 'info_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats)
      })
    ,
    'DESCRIPTOR' : _BLOCKINFO_STATUS,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo.Status)
    })
  ,
  'DESCRIPTOR' : _BLOCKINFO,
  '__module__' : 'info_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo)
  })
_sym_db.RegisterMessage(BlockInfo)
_sym_db.RegisterMessage(BlockInfo.Status)
_sym_db.RegisterMessage(BlockInfo.Status.Stats)

DeployInfo = _reflection.GeneratedProtocolMessageType('DeployInfo', (_message.Message,), {

  'ProcessingResult' : _reflection.GeneratedProtocolMessageType('ProcessingResult', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYINFO_PROCESSINGRESULT,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult)
    })
  ,

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYINFO_STATUS,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo.Status)
    })
  ,
  'DESCRIPTOR' : _DEPLOYINFO,
  '__module__' : 'info_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo)
  })
_sym_db.RegisterMessage(DeployInfo)
_sym_db.RegisterMessage(DeployInfo.ProcessingResult)
_sym_db.RegisterMessage(DeployInfo.Status)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {

  'BlockAdded' : _reflection.GeneratedProtocolMessageType('BlockAdded', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_BLOCKADDED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.BlockAdded)
    })
  ,

  'NewFinalizedBlock' : _reflection.GeneratedProtocolMessageType('NewFinalizedBlock', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_NEWFINALIZEDBLOCK,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.NewFinalizedBlock)
    })
  ,

  'DeployAdded' : _reflection.GeneratedProtocolMessageType('DeployAdded', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYADDED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployAdded)
    })
  ,

  'DeployDiscarded' : _reflection.GeneratedProtocolMessageType('DeployDiscarded', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYDISCARDED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployDiscarded)
    })
  ,

  'DeployRequeued' : _reflection.GeneratedProtocolMessageType('DeployRequeued', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYREQUEUED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployRequeued)
    })
  ,

  'DeployProcessed' : _reflection.GeneratedProtocolMessageType('DeployProcessed', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYPROCESSED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployProcessed)
    })
  ,

  'DeployFinalized' : _reflection.GeneratedProtocolMessageType('DeployFinalized', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYFINALIZED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployFinalized)
    })
  ,

  'DeployOrphaned' : _reflection.GeneratedProtocolMessageType('DeployOrphaned', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_DEPLOYORPHANED,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event.DeployOrphaned)
    })
  ,
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'info_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.Event)
  })
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.BlockAdded)
_sym_db.RegisterMessage(Event.NewFinalizedBlock)
_sym_db.RegisterMessage(Event.DeployAdded)
_sym_db.RegisterMessage(Event.DeployDiscarded)
_sym_db.RegisterMessage(Event.DeployRequeued)
_sym_db.RegisterMessage(Event.DeployProcessed)
_sym_db.RegisterMessage(Event.DeployFinalized)
_sym_db.RegisterMessage(Event.DeployOrphaned)


# @@protoc_insertion_point(module_scope)
