# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gossiping.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import empty_pb2 as empty__pb2
from . import consensus_pb2 as consensus__pb2
from . import node_pb2 as node__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gossiping.proto',
  package='io.casperlabs.comm.gossiping',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fgossiping.proto\x12\x1cio.casperlabs.comm.gossiping\x1a\x0b\x65mpty.proto\x1a\x0f\x63onsensus.proto\x1a\nnode.proto\"\\\n\x10NewBlocksRequest\x12\x32\n\x06sender\x18\x01 \x01(\x0b\x32\".io.casperlabs.comm.discovery.Node\x12\x14\n\x0c\x62lock_hashes\x18\x02 \x03(\x0c\"#\n\x11NewBlocksResponse\x12\x0e\n\x06is_new\x18\x01 \x01(\x08\"^\n\x11NewDeploysRequest\x12\x32\n\x06sender\x18\x01 \x01(\x0b\x32\".io.casperlabs.comm.discovery.Node\x12\x15\n\rdeploy_hashes\x18\x02 \x03(\x0c\"$\n\x12NewDeploysResponse\x12\x0e\n\x06is_new\x18\x01 \x01(\x08\"3\n\x1bStreamBlockSummariesRequest\x12\x14\n\x0c\x62lock_hashes\x18\x01 \x03(\x0c\"5\n\x1cStreamDeploySummariesRequest\x12\x15\n\rdeploy_hashes\x18\x01 \x03(\x0c\"q\n#StreamAncestorBlockSummariesRequest\x12\x1b\n\x13target_block_hashes\x18\x01 \x03(\x0c\x12\x1a\n\x12known_block_hashes\x18\x02 \x03(\x0c\x12\x11\n\tmax_depth\x18\x03 \x01(\r\"\x1d\n\x1bStreamLatestMessagesRequest\"\xac\x01\n\x16GetBlockChunkedRequest\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12\x12\n\nchunk_size\x18\x02 \x01(\r\x12\'\n\x1f\x61\x63\x63\x65pted_compression_algorithms\x18\x03 \x03(\t\x12\x1d\n\x15\x65xclude_deploy_bodies\x18\x04 \x01(\x08\x12\"\n\x1aonly_include_deploy_hashes\x18\x05 \x01(\x08\"q\n\x1bStreamDeploysChunkedRequest\x12\x15\n\rdeploy_hashes\x18\x01 \x03(\x0c\x12\x12\n\nchunk_size\x18\x02 \x01(\r\x12\'\n\x1f\x61\x63\x63\x65pted_compression_algorithms\x18\x03 \x03(\t\"\x1c\n\x1aGetGenesisCandidateRequest\"d\n\x12\x41\x64\x64\x41pprovalRequest\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12:\n\x08\x61pproval\x18\x02 \x01(\x0b\x32(.io.casperlabs.casper.consensus.Approval\"\xc2\x01\n\x05\x43hunk\x12<\n\x06header\x18\x01 \x01(\x0b\x32*.io.casperlabs.comm.gossiping.Chunk.HeaderH\x00\x12\x0e\n\x04\x64\x61ta\x18\x02 \x01(\x0cH\x00\x1a`\n\x06Header\x12\x1d\n\x15\x63ompression_algorithm\x18\x01 \x01(\t\x12\x16\n\x0e\x63ontent_length\x18\x02 \x01(\r\x12\x1f\n\x17original_content_length\x18\x03 \x01(\rB\t\n\x07\x63ontent\"K\n#StreamDagSliceBlockSummariesRequest\x12\x12\n\nstart_rank\x18\x01 \x01(\x04\x12\x10\n\x08\x65nd_rank\x18\x02 \x01(\x04\x32\xf3\n\n\rGossipService\x12l\n\tNewBlocks\x12..io.casperlabs.comm.gossiping.NewBlocksRequest\x1a/.io.casperlabs.comm.gossiping.NewBlocksResponse\x12o\n\nNewDeploys\x12/.io.casperlabs.comm.gossiping.NewDeploysRequest\x1a\x30.io.casperlabs.comm.gossiping.NewDeploysResponse\x12\x91\x01\n\x1cStreamAncestorBlockSummaries\x12\x41.io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest\x1a,.io.casperlabs.casper.consensus.BlockSummary0\x01\x12\x88\x01\n\x14StreamLatestMessages\x12\x39.io.casperlabs.comm.gossiping.StreamLatestMessagesRequest\x1a\x33.io.casperlabs.casper.consensus.Block.Justification0\x01\x12\x81\x01\n\x14StreamBlockSummaries\x12\x39.io.casperlabs.comm.gossiping.StreamBlockSummariesRequest\x1a,.io.casperlabs.casper.consensus.BlockSummary0\x01\x12\x84\x01\n\x15StreamDeploySummaries\x12:.io.casperlabs.comm.gossiping.StreamDeploySummariesRequest\x1a-.io.casperlabs.casper.consensus.DeploySummary0\x01\x12n\n\x0fGetBlockChunked\x12\x34.io.casperlabs.comm.gossiping.GetBlockChunkedRequest\x1a#.io.casperlabs.comm.gossiping.Chunk0\x01\x12x\n\x14StreamDeploysChunked\x12\x39.io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest\x1a#.io.casperlabs.comm.gossiping.Chunk0\x01\x12\x81\x01\n\x13GetGenesisCandidate\x12\x38.io.casperlabs.comm.gossiping.GetGenesisCandidateRequest\x1a\x30.io.casperlabs.casper.consensus.GenesisCandidate\x12W\n\x0b\x41\x64\x64\x41pproval\x12\x30.io.casperlabs.comm.gossiping.AddApprovalRequest\x1a\x16.google.protobuf.Empty\x12\x91\x01\n\x1cStreamDagSliceBlockSummaries\x12\x41.io.casperlabs.comm.gossiping.StreamDagSliceBlockSummariesRequest\x1a,.io.casperlabs.casper.consensus.BlockSummary0\x01\x62\x06proto3'
  ,
  dependencies=[empty__pb2.DESCRIPTOR,consensus__pb2.DESCRIPTOR,node__pb2.DESCRIPTOR,])




_NEWBLOCKSREQUEST = _descriptor.Descriptor(
  name='NewBlocksRequest',
  full_name='io.casperlabs.comm.gossiping.NewBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='io.casperlabs.comm.gossiping.NewBlocksRequest.sender', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_hashes', full_name='io.casperlabs.comm.gossiping.NewBlocksRequest.block_hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=183,
)


_NEWBLOCKSRESPONSE = _descriptor.Descriptor(
  name='NewBlocksResponse',
  full_name='io.casperlabs.comm.gossiping.NewBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_new', full_name='io.casperlabs.comm.gossiping.NewBlocksResponse.is_new', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=220,
)


_NEWDEPLOYSREQUEST = _descriptor.Descriptor(
  name='NewDeploysRequest',
  full_name='io.casperlabs.comm.gossiping.NewDeploysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='io.casperlabs.comm.gossiping.NewDeploysRequest.sender', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_hashes', full_name='io.casperlabs.comm.gossiping.NewDeploysRequest.deploy_hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=316,
)


_NEWDEPLOYSRESPONSE = _descriptor.Descriptor(
  name='NewDeploysResponse',
  full_name='io.casperlabs.comm.gossiping.NewDeploysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_new', full_name='io.casperlabs.comm.gossiping.NewDeploysResponse.is_new', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=354,
)


_STREAMBLOCKSUMMARIESREQUEST = _descriptor.Descriptor(
  name='StreamBlockSummariesRequest',
  full_name='io.casperlabs.comm.gossiping.StreamBlockSummariesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hashes', full_name='io.casperlabs.comm.gossiping.StreamBlockSummariesRequest.block_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=407,
)


_STREAMDEPLOYSUMMARIESREQUEST = _descriptor.Descriptor(
  name='StreamDeploySummariesRequest',
  full_name='io.casperlabs.comm.gossiping.StreamDeploySummariesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hashes', full_name='io.casperlabs.comm.gossiping.StreamDeploySummariesRequest.deploy_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=462,
)


_STREAMANCESTORBLOCKSUMMARIESREQUEST = _descriptor.Descriptor(
  name='StreamAncestorBlockSummariesRequest',
  full_name='io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_block_hashes', full_name='io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest.target_block_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='known_block_hashes', full_name='io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest.known_block_hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_depth', full_name='io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest.max_depth', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=577,
)


_STREAMLATESTMESSAGESREQUEST = _descriptor.Descriptor(
  name='StreamLatestMessagesRequest',
  full_name='io.casperlabs.comm.gossiping.StreamLatestMessagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=608,
)


_GETBLOCKCHUNKEDREQUEST = _descriptor.Descriptor(
  name='GetBlockChunkedRequest',
  full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest.chunk_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted_compression_algorithms', full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest.accepted_compression_algorithms', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_deploy_bodies', full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest.exclude_deploy_bodies', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_include_deploy_hashes', full_name='io.casperlabs.comm.gossiping.GetBlockChunkedRequest.only_include_deploy_hashes', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=783,
)


_STREAMDEPLOYSCHUNKEDREQUEST = _descriptor.Descriptor(
  name='StreamDeploysChunkedRequest',
  full_name='io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hashes', full_name='io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest.deploy_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest.chunk_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted_compression_algorithms', full_name='io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest.accepted_compression_algorithms', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=898,
)


_GETGENESISCANDIDATEREQUEST = _descriptor.Descriptor(
  name='GetGenesisCandidateRequest',
  full_name='io.casperlabs.comm.gossiping.GetGenesisCandidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=928,
)


_ADDAPPROVALREQUEST = _descriptor.Descriptor(
  name='AddApprovalRequest',
  full_name='io.casperlabs.comm.gossiping.AddApprovalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.comm.gossiping.AddApprovalRequest.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approval', full_name='io.casperlabs.comm.gossiping.AddApprovalRequest.approval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=930,
  serialized_end=1030,
)


_CHUNK_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='io.casperlabs.comm.gossiping.Chunk.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compression_algorithm', full_name='io.casperlabs.comm.gossiping.Chunk.Header.compression_algorithm', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='io.casperlabs.comm.gossiping.Chunk.Header.content_length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_content_length', full_name='io.casperlabs.comm.gossiping.Chunk.Header.original_content_length', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1216,
)

_CHUNK = _descriptor.Descriptor(
  name='Chunk',
  full_name='io.casperlabs.comm.gossiping.Chunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='io.casperlabs.comm.gossiping.Chunk.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='io.casperlabs.comm.gossiping.Chunk.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHUNK_HEADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='io.casperlabs.comm.gossiping.Chunk.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1033,
  serialized_end=1227,
)


_STREAMDAGSLICEBLOCKSUMMARIESREQUEST = _descriptor.Descriptor(
  name='StreamDagSliceBlockSummariesRequest',
  full_name='io.casperlabs.comm.gossiping.StreamDagSliceBlockSummariesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_rank', full_name='io.casperlabs.comm.gossiping.StreamDagSliceBlockSummariesRequest.start_rank', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_rank', full_name='io.casperlabs.comm.gossiping.StreamDagSliceBlockSummariesRequest.end_rank', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1304,
)

_NEWBLOCKSREQUEST.fields_by_name['sender'].message_type = node__pb2._NODE
_NEWDEPLOYSREQUEST.fields_by_name['sender'].message_type = node__pb2._NODE
_ADDAPPROVALREQUEST.fields_by_name['approval'].message_type = consensus__pb2._APPROVAL
_CHUNK_HEADER.containing_type = _CHUNK
_CHUNK.fields_by_name['header'].message_type = _CHUNK_HEADER
_CHUNK.oneofs_by_name['content'].fields.append(
  _CHUNK.fields_by_name['header'])
_CHUNK.fields_by_name['header'].containing_oneof = _CHUNK.oneofs_by_name['content']
_CHUNK.oneofs_by_name['content'].fields.append(
  _CHUNK.fields_by_name['data'])
_CHUNK.fields_by_name['data'].containing_oneof = _CHUNK.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['NewBlocksRequest'] = _NEWBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['NewBlocksResponse'] = _NEWBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['NewDeploysRequest'] = _NEWDEPLOYSREQUEST
DESCRIPTOR.message_types_by_name['NewDeploysResponse'] = _NEWDEPLOYSRESPONSE
DESCRIPTOR.message_types_by_name['StreamBlockSummariesRequest'] = _STREAMBLOCKSUMMARIESREQUEST
DESCRIPTOR.message_types_by_name['StreamDeploySummariesRequest'] = _STREAMDEPLOYSUMMARIESREQUEST
DESCRIPTOR.message_types_by_name['StreamAncestorBlockSummariesRequest'] = _STREAMANCESTORBLOCKSUMMARIESREQUEST
DESCRIPTOR.message_types_by_name['StreamLatestMessagesRequest'] = _STREAMLATESTMESSAGESREQUEST
DESCRIPTOR.message_types_by_name['GetBlockChunkedRequest'] = _GETBLOCKCHUNKEDREQUEST
DESCRIPTOR.message_types_by_name['StreamDeploysChunkedRequest'] = _STREAMDEPLOYSCHUNKEDREQUEST
DESCRIPTOR.message_types_by_name['GetGenesisCandidateRequest'] = _GETGENESISCANDIDATEREQUEST
DESCRIPTOR.message_types_by_name['AddApprovalRequest'] = _ADDAPPROVALREQUEST
DESCRIPTOR.message_types_by_name['Chunk'] = _CHUNK
DESCRIPTOR.message_types_by_name['StreamDagSliceBlockSummariesRequest'] = _STREAMDAGSLICEBLOCKSUMMARIESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewBlocksRequest = _reflection.GeneratedProtocolMessageType('NewBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWBLOCKSREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.NewBlocksRequest)
  })
_sym_db.RegisterMessage(NewBlocksRequest)

NewBlocksResponse = _reflection.GeneratedProtocolMessageType('NewBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWBLOCKSRESPONSE,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.NewBlocksResponse)
  })
_sym_db.RegisterMessage(NewBlocksResponse)

NewDeploysRequest = _reflection.GeneratedProtocolMessageType('NewDeploysRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWDEPLOYSREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.NewDeploysRequest)
  })
_sym_db.RegisterMessage(NewDeploysRequest)

NewDeploysResponse = _reflection.GeneratedProtocolMessageType('NewDeploysResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWDEPLOYSRESPONSE,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.NewDeploysResponse)
  })
_sym_db.RegisterMessage(NewDeploysResponse)

StreamBlockSummariesRequest = _reflection.GeneratedProtocolMessageType('StreamBlockSummariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKSUMMARIESREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamBlockSummariesRequest)
  })
_sym_db.RegisterMessage(StreamBlockSummariesRequest)

StreamDeploySummariesRequest = _reflection.GeneratedProtocolMessageType('StreamDeploySummariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDEPLOYSUMMARIESREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamDeploySummariesRequest)
  })
_sym_db.RegisterMessage(StreamDeploySummariesRequest)

StreamAncestorBlockSummariesRequest = _reflection.GeneratedProtocolMessageType('StreamAncestorBlockSummariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMANCESTORBLOCKSUMMARIESREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamAncestorBlockSummariesRequest)
  })
_sym_db.RegisterMessage(StreamAncestorBlockSummariesRequest)

StreamLatestMessagesRequest = _reflection.GeneratedProtocolMessageType('StreamLatestMessagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLATESTMESSAGESREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamLatestMessagesRequest)
  })
_sym_db.RegisterMessage(StreamLatestMessagesRequest)

GetBlockChunkedRequest = _reflection.GeneratedProtocolMessageType('GetBlockChunkedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKCHUNKEDREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.GetBlockChunkedRequest)
  })
_sym_db.RegisterMessage(GetBlockChunkedRequest)

StreamDeploysChunkedRequest = _reflection.GeneratedProtocolMessageType('StreamDeploysChunkedRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDEPLOYSCHUNKEDREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamDeploysChunkedRequest)
  })
_sym_db.RegisterMessage(StreamDeploysChunkedRequest)

GetGenesisCandidateRequest = _reflection.GeneratedProtocolMessageType('GetGenesisCandidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGENESISCANDIDATEREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.GetGenesisCandidateRequest)
  })
_sym_db.RegisterMessage(GetGenesisCandidateRequest)

AddApprovalRequest = _reflection.GeneratedProtocolMessageType('AddApprovalRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAPPROVALREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.AddApprovalRequest)
  })
_sym_db.RegisterMessage(AddApprovalRequest)

Chunk = _reflection.GeneratedProtocolMessageType('Chunk', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _CHUNK_HEADER,
    '__module__' : 'gossiping_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.Chunk.Header)
    })
  ,
  'DESCRIPTOR' : _CHUNK,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.Chunk)
  })
_sym_db.RegisterMessage(Chunk)
_sym_db.RegisterMessage(Chunk.Header)

StreamDagSliceBlockSummariesRequest = _reflection.GeneratedProtocolMessageType('StreamDagSliceBlockSummariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDAGSLICEBLOCKSUMMARIESREQUEST,
  '__module__' : 'gossiping_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.comm.gossiping.StreamDagSliceBlockSummariesRequest)
  })
_sym_db.RegisterMessage(StreamDagSliceBlockSummariesRequest)



_GOSSIPSERVICE = _descriptor.ServiceDescriptor(
  name='GossipService',
  full_name='io.casperlabs.comm.gossiping.GossipService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1307,
  serialized_end=2702,
  methods=[
  _descriptor.MethodDescriptor(
    name='NewBlocks',
    full_name='io.casperlabs.comm.gossiping.GossipService.NewBlocks',
    index=0,
    containing_service=None,
    input_type=_NEWBLOCKSREQUEST,
    output_type=_NEWBLOCKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewDeploys',
    full_name='io.casperlabs.comm.gossiping.GossipService.NewDeploys',
    index=1,
    containing_service=None,
    input_type=_NEWDEPLOYSREQUEST,
    output_type=_NEWDEPLOYSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamAncestorBlockSummaries',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamAncestorBlockSummaries',
    index=2,
    containing_service=None,
    input_type=_STREAMANCESTORBLOCKSUMMARIESREQUEST,
    output_type=consensus__pb2._BLOCKSUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamLatestMessages',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamLatestMessages',
    index=3,
    containing_service=None,
    input_type=_STREAMLATESTMESSAGESREQUEST,
    output_type=consensus__pb2._BLOCK_JUSTIFICATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlockSummaries',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamBlockSummaries',
    index=4,
    containing_service=None,
    input_type=_STREAMBLOCKSUMMARIESREQUEST,
    output_type=consensus__pb2._BLOCKSUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamDeploySummaries',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamDeploySummaries',
    index=5,
    containing_service=None,
    input_type=_STREAMDEPLOYSUMMARIESREQUEST,
    output_type=consensus__pb2._DEPLOYSUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockChunked',
    full_name='io.casperlabs.comm.gossiping.GossipService.GetBlockChunked',
    index=6,
    containing_service=None,
    input_type=_GETBLOCKCHUNKEDREQUEST,
    output_type=_CHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamDeploysChunked',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamDeploysChunked',
    index=7,
    containing_service=None,
    input_type=_STREAMDEPLOYSCHUNKEDREQUEST,
    output_type=_CHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGenesisCandidate',
    full_name='io.casperlabs.comm.gossiping.GossipService.GetGenesisCandidate',
    index=8,
    containing_service=None,
    input_type=_GETGENESISCANDIDATEREQUEST,
    output_type=consensus__pb2._GENESISCANDIDATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddApproval',
    full_name='io.casperlabs.comm.gossiping.GossipService.AddApproval',
    index=9,
    containing_service=None,
    input_type=_ADDAPPROVALREQUEST,
    output_type=empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamDagSliceBlockSummaries',
    full_name='io.casperlabs.comm.gossiping.GossipService.StreamDagSliceBlockSummaries',
    index=10,
    containing_service=None,
    input_type=_STREAMDAGSLICEBLOCKSUMMARIESREQUEST,
    output_type=consensus__pb2._BLOCKSUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GOSSIPSERVICE)

DESCRIPTOR.services_by_name['GossipService'] = _GOSSIPSERVICE

# @@protoc_insertion_point(module_scope)
