# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: consensus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import state_pb2 as state__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='consensus.proto',
  package='io.casperlabs.casper.consensus',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x63onsensus.proto\x12\x1eio.casperlabs.casper.consensus\x1a\x0bstate.proto\"/\n\tSignature\x12\x15\n\rsig_algorithm\x18\x01 \x01(\t\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"e\n\x08\x41pproval\x12\x1b\n\x13\x61pprover_public_key\x18\x01 \x01(\x0c\x12<\n\tsignature\x18\x02 \x01(\x0b\x32).io.casperlabs.casper.consensus.Signature\"\xcb\x0e\n\x06\x44\x65ploy\x12\x13\n\x0b\x64\x65ploy_hash\x18\x01 \x01(\x0c\x12=\n\x06header\x18\x02 \x01(\x0b\x32-.io.casperlabs.casper.consensus.Deploy.Header\x12\x39\n\x04\x62ody\x18\x03 \x01(\x0b\x32+.io.casperlabs.casper.consensus.Deploy.Body\x12;\n\tapprovals\x18\x04 \x03(\x0b\x32(.io.casperlabs.casper.consensus.Approval\x1a\xa6\x01\n\x06Header\x12\x1f\n\x17\x61\x63\x63ount_public_key_hash\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x11\n\tgas_price\x18\x04 \x01(\x04\x12\x11\n\tbody_hash\x18\x05 \x01(\x0c\x12\x12\n\nttl_millis\x18\x06 \x01(\r\x12\x14\n\x0c\x64\x65pendencies\x18\x07 \x03(\x0c\x12\x12\n\nchain_name\x18\x08 \x01(\tJ\x04\x08\x02\x10\x03\x1a\x82\x01\n\x04\x42ody\x12<\n\x07session\x18\x01 \x01(\x0b\x32+.io.casperlabs.casper.consensus.Deploy.Code\x12<\n\x07payment\x18\x02 \x01(\x0b\x32+.io.casperlabs.casper.consensus.Deploy.Code\x1a\xbc\x05\n\x04\x43ode\x12\x38\n\x04\x61rgs\x18\x01 \x03(\x0b\x32*.io.casperlabs.casper.consensus.Deploy.Arg\x12Q\n\rwasm_contract\x18\x02 \x01(\x0b\x32\x38.io.casperlabs.casper.consensus.Deploy.Code.WasmContractH\x00\x12U\n\x0fstored_contract\x18\x03 \x01(\x0b\x32:.io.casperlabs.casper.consensus.Deploy.Code.StoredContractH\x00\x12h\n\x19stored_versioned_contract\x18\x04 \x01(\x0b\x32\x43.io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContractH\x00\x12Y\n\x11transfer_contract\x18\x05 \x01(\x0b\x32<.io.casperlabs.casper.consensus.Deploy.Code.TransferContractH\x00\x1a\x1c\n\x0cWasmContract\x12\x0c\n\x04wasm\x18\x01 \x01(\x0c\x1ar\n\x17StoredVersionedContract\x12\x16\n\x0cpackage_hash\x18\x01 \x01(\x0cH\x00\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x13\n\x0b\x65ntry_point\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\rB\t\n\x07\x61\x64\x64ress\x1aY\n\x0eStoredContract\x12\x17\n\rcontract_hash\x18\x01 \x01(\x0cH\x00\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x13\n\x0b\x65ntry_point\x18\x03 \x01(\tB\t\n\x07\x61\x64\x64ress\x1a\x12\n\x10TransferContractB\n\n\x08\x63ontract\x1a_\n\x03\x41rg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x05value\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.CLValueInstanceJ\x04\x08\x02\x10\x03\x1a\xa6\x04\n\tLegacyArg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.Deploy.LegacyArg.Value\x1a\xc3\x03\n\x05Value\x12P\n\x0eoptional_value\x18\x01 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.Deploy.LegacyArg.ValueH\x00\x12\x15\n\x0b\x62ytes_value\x18\x02 \x01(\x0cH\x00\x12\x13\n\tint_value\x18\x03 \x01(\x05H\x00\x12\x41\n\x08int_list\x18\x04 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.IntListH\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x12G\n\x0bstring_list\x18\x06 \x01(\x0b\x32\x30.io.casperlabs.casper.consensus.state.StringListH\x00\x12\x14\n\nlong_value\x18\x07 \x01(\x03H\x00\x12?\n\x07\x62ig_int\x18\x08 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntH\x00\x12\x38\n\x03key\x18\t \x01(\x0b\x32).io.casperlabs.casper.consensus.state.KeyH\x00\x42\x07\n\x05value\"\xa0\x01\n\rDeploySummary\x12\x13\n\x0b\x64\x65ploy_hash\x18\x01 \x01(\x0c\x12=\n\x06header\x18\x02 \x01(\x0b\x32-.io.casperlabs.casper.consensus.Deploy.Header\x12;\n\tapprovals\x18\x03 \x03(\x0b\x32(.io.casperlabs.casper.consensus.Approval\"\x9e\x01\n\x0c\x42lockSummary\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12<\n\x06header\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.Block.Header\x12<\n\tsignature\x18\x03 \x01(\x0b\x32).io.casperlabs.casper.consensus.Signature\"\xb7\x0b\n\x05\x42lock\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12<\n\x06header\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.Block.Header\x12\x38\n\x04\x62ody\x18\x03 \x01(\x0b\x32*.io.casperlabs.casper.consensus.Block.Body\x12<\n\tsignature\x18\x04 \x01(\x0b\x32).io.casperlabs.casper.consensus.Signature\x1a\xcc\x05\n\x06Header\x12\x15\n\rparent_hashes\x18\x01 \x03(\x0c\x12K\n\x0ejustifications\x18\x02 \x03(\x0b\x32\x33.io.casperlabs.casper.consensus.Block.Justification\x12@\n\x05state\x18\x03 \x01(\x0b\x32\x31.io.casperlabs.casper.consensus.Block.GlobalState\x12\x11\n\tbody_hash\x18\x04 \x01(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x04\x12O\n\x10protocol_version\x18\r \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x12\x14\n\x0c\x64\x65ploy_count\x18\x07 \x01(\r\x12\x12\n\nchain_name\x18\x08 \x01(\t\x12\x1f\n\x17validator_block_seq_num\x18\t \x01(\r\x12\x1c\n\x14validator_public_key\x18\n \x01(\x0c\x12!\n\x19validator_public_key_hash\x18\x14 \x01(\x0c\x12!\n\x19validator_prev_block_hash\x18\x0e \x01(\x0c\x12\x0e\n\x06j_rank\x18\x0b \x01(\x04\x12G\n\x0cmessage_type\x18\x0c \x01(\x0e\x32\x31.io.casperlabs.casper.consensus.Block.MessageType\x12G\n\x0cmessage_role\x18\x13 \x01(\x0e\x32\x31.io.casperlabs.casper.consensus.Block.MessageRole\x12\x16\n\x0ekey_block_hash\x18\x0f \x01(\x0c\x12\x10\n\x08round_id\x18\x10 \x01(\x04\x12\x11\n\tmagic_bit\x18\x11 \x01(\x08\x12\x11\n\tmain_rank\x18\x12 \x01(\x04J\x04\x08\x06\x10\x07\x1aN\n\x04\x42ody\x12\x46\n\x07\x64\x65ploys\x18\x01 \x03(\x0b\x32\x35.io.casperlabs.casper.consensus.Block.ProcessedDeploy\x1aM\n\rJustification\x12!\n\x19validator_public_key_hash\x18\x01 \x01(\x0c\x12\x19\n\x11latest_block_hash\x18\x02 \x01(\x0c\x1a\x8f\x01\n\x0fProcessedDeploy\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x04\x12\x10\n\x08is_error\x18\x03 \x01(\x08\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\r\x1as\n\x0bGlobalState\x12\x16\n\x0epre_state_hash\x18\x01 \x01(\x0c\x12\x17\n\x0fpost_state_hash\x18\x02 \x01(\x0c\x12\x33\n\x05\x62onds\x18\x03 \x03(\x0b\x32$.io.casperlabs.casper.consensus.Bond\"$\n\x0bMessageType\x12\t\n\x05\x42LOCK\x10\x00\x12\n\n\x06\x42\x41LLOT\x10\x01\"I\n\x0bMessageRole\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08PROPOSAL\x10\x01\x12\x10\n\x0c\x43ONFIRMATION\x10\x02\x12\x0b\n\x07WITNESS\x10\x03\"l\n\x04\x42ond\x12!\n\x19validator_public_key_hash\x18\x01 \x01(\x0c\x12;\n\x05stake\x18\x03 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntJ\x04\x08\x02\x10\x03\"c\n\x10GenesisCandidate\x12\x12\n\nblock_hash\x18\x01 \x01(\x0c\x12;\n\tapprovals\x18\x02 \x03(\x0b\x32(.io.casperlabs.casper.consensus.Approval\"\xc8\x01\n\x03\x45ra\x12\x16\n\x0ekey_block_hash\x18\x01 \x01(\x0c\x12\x1d\n\x15parent_key_block_hash\x18\x02 \x01(\x0c\x12\x12\n\nstart_tick\x18\x03 \x01(\x04\x12\x10\n\x08\x65nd_tick\x18\x04 \x01(\x04\x12\x1a\n\x12\x62ooking_block_hash\x18\x05 \x01(\x0c\x12\x13\n\x0bleader_seed\x18\x06 \x01(\x0c\x12\x33\n\x05\x62onds\x18\x07 \x03(\x0b\x32$.io.casperlabs.casper.consensus.Bondb\x06proto3'
  ,
  dependencies=[state__pb2.DESCRIPTOR,])



_BLOCK_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='io.casperlabs.casper.consensus.Block.MessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLOCK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BALLOT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3763,
  serialized_end=3799,
)
_sym_db.RegisterEnumDescriptor(_BLOCK_MESSAGETYPE)

_BLOCK_MESSAGEROLE = _descriptor.EnumDescriptor(
  name='MessageRole',
  full_name='io.casperlabs.casper.consensus.Block.MessageRole',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIRMATION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WITNESS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3801,
  serialized_end=3874,
)
_sym_db.RegisterEnumDescriptor(_BLOCK_MESSAGEROLE)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='io.casperlabs.casper.consensus.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sig_algorithm', full_name='io.casperlabs.casper.consensus.Signature.sig_algorithm', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sig', full_name='io.casperlabs.casper.consensus.Signature.sig', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=111,
)


_APPROVAL = _descriptor.Descriptor(
  name='Approval',
  full_name='io.casperlabs.casper.consensus.Approval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='approver_public_key', full_name='io.casperlabs.casper.consensus.Approval.approver_public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='io.casperlabs.casper.consensus.Approval.signature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=214,
)


_DEPLOY_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='io.casperlabs.casper.consensus.Deploy.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_public_key_hash', full_name='io.casperlabs.casper.consensus.Deploy.Header.account_public_key_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='io.casperlabs.casper.consensus.Deploy.Header.timestamp', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='io.casperlabs.casper.consensus.Deploy.Header.gas_price', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_hash', full_name='io.casperlabs.casper.consensus.Deploy.Header.body_hash', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_millis', full_name='io.casperlabs.casper.consensus.Deploy.Header.ttl_millis', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='io.casperlabs.casper.consensus.Deploy.Header.dependencies', index=5,
      number=7, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_name', full_name='io.casperlabs.casper.consensus.Deploy.Header.chain_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=598,
)

_DEPLOY_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='io.casperlabs.casper.consensus.Deploy.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='io.casperlabs.casper.consensus.Deploy.Body.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment', full_name='io.casperlabs.casper.consensus.Deploy.Body.payment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=731,
)

_DEPLOY_CODE_WASMCONTRACT = _descriptor.Descriptor(
  name='WasmContract',
  full_name='io.casperlabs.casper.consensus.Deploy.Code.WasmContract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wasm', full_name='io.casperlabs.casper.consensus.Deploy.Code.WasmContract.wasm', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1195,
)

_DEPLOY_CODE_STOREDVERSIONEDCONTRACT = _descriptor.Descriptor(
  name='StoredVersionedContract',
  full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_hash', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract.package_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract.entry_point', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract.version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1197,
  serialized_end=1311,
)

_DEPLOY_CODE_STOREDCONTRACT = _descriptor.Descriptor(
  name='StoredContract',
  full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredContract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_hash', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredContract.contract_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredContract.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredContract.entry_point', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='io.casperlabs.casper.consensus.Deploy.Code.StoredContract.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1313,
  serialized_end=1402,
)

_DEPLOY_CODE_TRANSFERCONTRACT = _descriptor.Descriptor(
  name='TransferContract',
  full_name='io.casperlabs.casper.consensus.Deploy.Code.TransferContract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1422,
)

_DEPLOY_CODE = _descriptor.Descriptor(
  name='Code',
  full_name='io.casperlabs.casper.consensus.Deploy.Code',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.casper.consensus.Deploy.Code.args', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wasm_contract', full_name='io.casperlabs.casper.consensus.Deploy.Code.wasm_contract', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_contract', full_name='io.casperlabs.casper.consensus.Deploy.Code.stored_contract', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_versioned_contract', full_name='io.casperlabs.casper.consensus.Deploy.Code.stored_versioned_contract', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_contract', full_name='io.casperlabs.casper.consensus.Deploy.Code.transfer_contract', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOY_CODE_WASMCONTRACT, _DEPLOY_CODE_STOREDVERSIONEDCONTRACT, _DEPLOY_CODE_STOREDCONTRACT, _DEPLOY_CODE_TRANSFERCONTRACT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.Deploy.Code.contract',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=734,
  serialized_end=1434,
)

_DEPLOY_ARG = _descriptor.Descriptor(
  name='Arg',
  full_name='io.casperlabs.casper.consensus.Deploy.Arg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.Deploy.Arg.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.Deploy.Arg.value', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1531,
)

_DEPLOY_LEGACYARG_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.optional_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.bytes_value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.int_value', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_list', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.int_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.string_list', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.long_value', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='big_int', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.big_int', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.key', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.Value.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1633,
  serialized_end=2084,
)

_DEPLOY_LEGACYARG = _descriptor.Descriptor(
  name='LegacyArg',
  full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.Deploy.LegacyArg.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOY_LEGACYARG_VALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=2084,
)

_DEPLOY = _descriptor.Descriptor(
  name='Deploy',
  full_name='io.casperlabs.casper.consensus.Deploy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hash', full_name='io.casperlabs.casper.consensus.Deploy.deploy_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='io.casperlabs.casper.consensus.Deploy.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='io.casperlabs.casper.consensus.Deploy.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approvals', full_name='io.casperlabs.casper.consensus.Deploy.approvals', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOY_HEADER, _DEPLOY_BODY, _DEPLOY_CODE, _DEPLOY_ARG, _DEPLOY_LEGACYARG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=2084,
)


_DEPLOYSUMMARY = _descriptor.Descriptor(
  name='DeploySummary',
  full_name='io.casperlabs.casper.consensus.DeploySummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hash', full_name='io.casperlabs.casper.consensus.DeploySummary.deploy_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='io.casperlabs.casper.consensus.DeploySummary.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approvals', full_name='io.casperlabs.casper.consensus.DeploySummary.approvals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2087,
  serialized_end=2247,
)


_BLOCKSUMMARY = _descriptor.Descriptor(
  name='BlockSummary',
  full_name='io.casperlabs.casper.consensus.BlockSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.BlockSummary.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='io.casperlabs.casper.consensus.BlockSummary.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='io.casperlabs.casper.consensus.BlockSummary.signature', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2250,
  serialized_end=2408,
)


_BLOCK_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='io.casperlabs.casper.consensus.Block.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_hashes', full_name='io.casperlabs.casper.consensus.Block.Header.parent_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='justifications', full_name='io.casperlabs.casper.consensus.Block.Header.justifications', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='io.casperlabs.casper.consensus.Block.Header.state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_hash', full_name='io.casperlabs.casper.consensus.Block.Header.body_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='io.casperlabs.casper.consensus.Block.Header.timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.casper.consensus.Block.Header.protocol_version', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_count', full_name='io.casperlabs.casper.consensus.Block.Header.deploy_count', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_name', full_name='io.casperlabs.casper.consensus.Block.Header.chain_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_block_seq_num', full_name='io.casperlabs.casper.consensus.Block.Header.validator_block_seq_num', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_public_key', full_name='io.casperlabs.casper.consensus.Block.Header.validator_public_key', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_public_key_hash', full_name='io.casperlabs.casper.consensus.Block.Header.validator_public_key_hash', index=10,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_prev_block_hash', full_name='io.casperlabs.casper.consensus.Block.Header.validator_prev_block_hash', index=11,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_rank', full_name='io.casperlabs.casper.consensus.Block.Header.j_rank', index=12,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='io.casperlabs.casper.consensus.Block.Header.message_type', index=13,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_role', full_name='io.casperlabs.casper.consensus.Block.Header.message_role', index=14,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_block_hash', full_name='io.casperlabs.casper.consensus.Block.Header.key_block_hash', index=15,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round_id', full_name='io.casperlabs.casper.consensus.Block.Header.round_id', index=16,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='magic_bit', full_name='io.casperlabs.casper.consensus.Block.Header.magic_bit', index=17,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_rank', full_name='io.casperlabs.casper.consensus.Block.Header.main_rank', index=18,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2623,
  serialized_end=3339,
)

_BLOCK_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='io.casperlabs.casper.consensus.Block.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploys', full_name='io.casperlabs.casper.consensus.Block.Body.deploys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3341,
  serialized_end=3419,
)

_BLOCK_JUSTIFICATION = _descriptor.Descriptor(
  name='Justification',
  full_name='io.casperlabs.casper.consensus.Block.Justification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_public_key_hash', full_name='io.casperlabs.casper.consensus.Block.Justification.validator_public_key_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_block_hash', full_name='io.casperlabs.casper.consensus.Block.Justification.latest_block_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3421,
  serialized_end=3498,
)

_BLOCK_PROCESSEDDEPLOY = _descriptor.Descriptor(
  name='ProcessedDeploy',
  full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy.cost', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_error', full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy.is_error', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy.error_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='io.casperlabs.casper.consensus.Block.ProcessedDeploy.stage', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3501,
  serialized_end=3644,
)

_BLOCK_GLOBALSTATE = _descriptor.Descriptor(
  name='GlobalState',
  full_name='io.casperlabs.casper.consensus.Block.GlobalState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pre_state_hash', full_name='io.casperlabs.casper.consensus.Block.GlobalState.pre_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_state_hash', full_name='io.casperlabs.casper.consensus.Block.GlobalState.post_state_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='io.casperlabs.casper.consensus.Block.GlobalState.bonds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3646,
  serialized_end=3761,
)

_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='io.casperlabs.casper.consensus.Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.Block.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='io.casperlabs.casper.consensus.Block.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='io.casperlabs.casper.consensus.Block.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='io.casperlabs.casper.consensus.Block.signature', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BLOCK_HEADER, _BLOCK_BODY, _BLOCK_JUSTIFICATION, _BLOCK_PROCESSEDDEPLOY, _BLOCK_GLOBALSTATE, ],
  enum_types=[
    _BLOCK_MESSAGETYPE,
    _BLOCK_MESSAGEROLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=3874,
)


_BOND = _descriptor.Descriptor(
  name='Bond',
  full_name='io.casperlabs.casper.consensus.Bond',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_public_key_hash', full_name='io.casperlabs.casper.consensus.Bond.validator_public_key_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stake', full_name='io.casperlabs.casper.consensus.Bond.stake', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3876,
  serialized_end=3984,
)


_GENESISCANDIDATE = _descriptor.Descriptor(
  name='GenesisCandidate',
  full_name='io.casperlabs.casper.consensus.GenesisCandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='io.casperlabs.casper.consensus.GenesisCandidate.block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approvals', full_name='io.casperlabs.casper.consensus.GenesisCandidate.approvals', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3986,
  serialized_end=4085,
)


_ERA = _descriptor.Descriptor(
  name='Era',
  full_name='io.casperlabs.casper.consensus.Era',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_block_hash', full_name='io.casperlabs.casper.consensus.Era.key_block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_key_block_hash', full_name='io.casperlabs.casper.consensus.Era.parent_key_block_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_tick', full_name='io.casperlabs.casper.consensus.Era.start_tick', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_tick', full_name='io.casperlabs.casper.consensus.Era.end_tick', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='booking_block_hash', full_name='io.casperlabs.casper.consensus.Era.booking_block_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leader_seed', full_name='io.casperlabs.casper.consensus.Era.leader_seed', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='io.casperlabs.casper.consensus.Era.bonds', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4088,
  serialized_end=4288,
)

_APPROVAL.fields_by_name['signature'].message_type = _SIGNATURE
_DEPLOY_HEADER.containing_type = _DEPLOY
_DEPLOY_BODY.fields_by_name['session'].message_type = _DEPLOY_CODE
_DEPLOY_BODY.fields_by_name['payment'].message_type = _DEPLOY_CODE
_DEPLOY_BODY.containing_type = _DEPLOY
_DEPLOY_CODE_WASMCONTRACT.containing_type = _DEPLOY_CODE
_DEPLOY_CODE_STOREDVERSIONEDCONTRACT.containing_type = _DEPLOY_CODE
_DEPLOY_CODE_STOREDVERSIONEDCONTRACT.oneofs_by_name['address'].fields.append(
  _DEPLOY_CODE_STOREDVERSIONEDCONTRACT.fields_by_name['package_hash'])
_DEPLOY_CODE_STOREDVERSIONEDCONTRACT.fields_by_name['package_hash'].containing_oneof = _DEPLOY_CODE_STOREDVERSIONEDCONTRACT.oneofs_by_name['address']
_DEPLOY_CODE_STOREDVERSIONEDCONTRACT.oneofs_by_name['address'].fields.append(
  _DEPLOY_CODE_STOREDVERSIONEDCONTRACT.fields_by_name['name'])
_DEPLOY_CODE_STOREDVERSIONEDCONTRACT.fields_by_name['name'].containing_oneof = _DEPLOY_CODE_STOREDVERSIONEDCONTRACT.oneofs_by_name['address']
_DEPLOY_CODE_STOREDCONTRACT.containing_type = _DEPLOY_CODE
_DEPLOY_CODE_STOREDCONTRACT.oneofs_by_name['address'].fields.append(
  _DEPLOY_CODE_STOREDCONTRACT.fields_by_name['contract_hash'])
_DEPLOY_CODE_STOREDCONTRACT.fields_by_name['contract_hash'].containing_oneof = _DEPLOY_CODE_STOREDCONTRACT.oneofs_by_name['address']
_DEPLOY_CODE_STOREDCONTRACT.oneofs_by_name['address'].fields.append(
  _DEPLOY_CODE_STOREDCONTRACT.fields_by_name['name'])
_DEPLOY_CODE_STOREDCONTRACT.fields_by_name['name'].containing_oneof = _DEPLOY_CODE_STOREDCONTRACT.oneofs_by_name['address']
_DEPLOY_CODE_TRANSFERCONTRACT.containing_type = _DEPLOY_CODE
_DEPLOY_CODE.fields_by_name['args'].message_type = _DEPLOY_ARG
_DEPLOY_CODE.fields_by_name['wasm_contract'].message_type = _DEPLOY_CODE_WASMCONTRACT
_DEPLOY_CODE.fields_by_name['stored_contract'].message_type = _DEPLOY_CODE_STOREDCONTRACT
_DEPLOY_CODE.fields_by_name['stored_versioned_contract'].message_type = _DEPLOY_CODE_STOREDVERSIONEDCONTRACT
_DEPLOY_CODE.fields_by_name['transfer_contract'].message_type = _DEPLOY_CODE_TRANSFERCONTRACT
_DEPLOY_CODE.containing_type = _DEPLOY
_DEPLOY_CODE.oneofs_by_name['contract'].fields.append(
  _DEPLOY_CODE.fields_by_name['wasm_contract'])
_DEPLOY_CODE.fields_by_name['wasm_contract'].containing_oneof = _DEPLOY_CODE.oneofs_by_name['contract']
_DEPLOY_CODE.oneofs_by_name['contract'].fields.append(
  _DEPLOY_CODE.fields_by_name['stored_contract'])
_DEPLOY_CODE.fields_by_name['stored_contract'].containing_oneof = _DEPLOY_CODE.oneofs_by_name['contract']
_DEPLOY_CODE.oneofs_by_name['contract'].fields.append(
  _DEPLOY_CODE.fields_by_name['stored_versioned_contract'])
_DEPLOY_CODE.fields_by_name['stored_versioned_contract'].containing_oneof = _DEPLOY_CODE.oneofs_by_name['contract']
_DEPLOY_CODE.oneofs_by_name['contract'].fields.append(
  _DEPLOY_CODE.fields_by_name['transfer_contract'])
_DEPLOY_CODE.fields_by_name['transfer_contract'].containing_oneof = _DEPLOY_CODE.oneofs_by_name['contract']
_DEPLOY_ARG.fields_by_name['value'].message_type = state__pb2._CLVALUEINSTANCE
_DEPLOY_ARG.containing_type = _DEPLOY
_DEPLOY_LEGACYARG_VALUE.fields_by_name['optional_value'].message_type = _DEPLOY_LEGACYARG_VALUE
_DEPLOY_LEGACYARG_VALUE.fields_by_name['int_list'].message_type = state__pb2._INTLIST
_DEPLOY_LEGACYARG_VALUE.fields_by_name['string_list'].message_type = state__pb2._STRINGLIST
_DEPLOY_LEGACYARG_VALUE.fields_by_name['big_int'].message_type = state__pb2._BIGINT
_DEPLOY_LEGACYARG_VALUE.fields_by_name['key'].message_type = state__pb2._KEY
_DEPLOY_LEGACYARG_VALUE.containing_type = _DEPLOY_LEGACYARG
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['optional_value'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['optional_value'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['bytes_value'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['bytes_value'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['int_value'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['int_value'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['int_list'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['int_list'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['string_value'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['string_value'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['string_list'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['string_list'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['long_value'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['long_value'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['big_int'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['big_int'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value'].fields.append(
  _DEPLOY_LEGACYARG_VALUE.fields_by_name['key'])
_DEPLOY_LEGACYARG_VALUE.fields_by_name['key'].containing_oneof = _DEPLOY_LEGACYARG_VALUE.oneofs_by_name['value']
_DEPLOY_LEGACYARG.fields_by_name['value'].message_type = _DEPLOY_LEGACYARG_VALUE
_DEPLOY_LEGACYARG.containing_type = _DEPLOY
_DEPLOY.fields_by_name['header'].message_type = _DEPLOY_HEADER
_DEPLOY.fields_by_name['body'].message_type = _DEPLOY_BODY
_DEPLOY.fields_by_name['approvals'].message_type = _APPROVAL
_DEPLOYSUMMARY.fields_by_name['header'].message_type = _DEPLOY_HEADER
_DEPLOYSUMMARY.fields_by_name['approvals'].message_type = _APPROVAL
_BLOCKSUMMARY.fields_by_name['header'].message_type = _BLOCK_HEADER
_BLOCKSUMMARY.fields_by_name['signature'].message_type = _SIGNATURE
_BLOCK_HEADER.fields_by_name['justifications'].message_type = _BLOCK_JUSTIFICATION
_BLOCK_HEADER.fields_by_name['state'].message_type = _BLOCK_GLOBALSTATE
_BLOCK_HEADER.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_BLOCK_HEADER.fields_by_name['message_type'].enum_type = _BLOCK_MESSAGETYPE
_BLOCK_HEADER.fields_by_name['message_role'].enum_type = _BLOCK_MESSAGEROLE
_BLOCK_HEADER.containing_type = _BLOCK
_BLOCK_BODY.fields_by_name['deploys'].message_type = _BLOCK_PROCESSEDDEPLOY
_BLOCK_BODY.containing_type = _BLOCK
_BLOCK_JUSTIFICATION.containing_type = _BLOCK
_BLOCK_PROCESSEDDEPLOY.fields_by_name['deploy'].message_type = _DEPLOY
_BLOCK_PROCESSEDDEPLOY.containing_type = _BLOCK
_BLOCK_GLOBALSTATE.fields_by_name['bonds'].message_type = _BOND
_BLOCK_GLOBALSTATE.containing_type = _BLOCK
_BLOCK.fields_by_name['header'].message_type = _BLOCK_HEADER
_BLOCK.fields_by_name['body'].message_type = _BLOCK_BODY
_BLOCK.fields_by_name['signature'].message_type = _SIGNATURE
_BLOCK_MESSAGETYPE.containing_type = _BLOCK
_BLOCK_MESSAGEROLE.containing_type = _BLOCK
_BOND.fields_by_name['stake'].message_type = state__pb2._BIGINT
_GENESISCANDIDATE.fields_by_name['approvals'].message_type = _APPROVAL
_ERA.fields_by_name['bonds'].message_type = _BOND
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['Approval'] = _APPROVAL
DESCRIPTOR.message_types_by_name['Deploy'] = _DEPLOY
DESCRIPTOR.message_types_by_name['DeploySummary'] = _DEPLOYSUMMARY
DESCRIPTOR.message_types_by_name['BlockSummary'] = _BLOCKSUMMARY
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
DESCRIPTOR.message_types_by_name['Bond'] = _BOND
DESCRIPTOR.message_types_by_name['GenesisCandidate'] = _GENESISCANDIDATE
DESCRIPTOR.message_types_by_name['Era'] = _ERA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Signature)
  })
_sym_db.RegisterMessage(Signature)

Approval = _reflection.GeneratedProtocolMessageType('Approval', (_message.Message,), {
  'DESCRIPTOR' : _APPROVAL,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Approval)
  })
_sym_db.RegisterMessage(Approval)

Deploy = _reflection.GeneratedProtocolMessageType('Deploy', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOY_HEADER,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Header)
    })
  ,

  'Body' : _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOY_BODY,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Body)
    })
  ,

  'Code' : _reflection.GeneratedProtocolMessageType('Code', (_message.Message,), {

    'WasmContract' : _reflection.GeneratedProtocolMessageType('WasmContract', (_message.Message,), {
      'DESCRIPTOR' : _DEPLOY_CODE_WASMCONTRACT,
      '__module__' : 'consensus_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Code.WasmContract)
      })
    ,

    'StoredVersionedContract' : _reflection.GeneratedProtocolMessageType('StoredVersionedContract', (_message.Message,), {
      'DESCRIPTOR' : _DEPLOY_CODE_STOREDVERSIONEDCONTRACT,
      '__module__' : 'consensus_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Code.StoredVersionedContract)
      })
    ,

    'StoredContract' : _reflection.GeneratedProtocolMessageType('StoredContract', (_message.Message,), {
      'DESCRIPTOR' : _DEPLOY_CODE_STOREDCONTRACT,
      '__module__' : 'consensus_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Code.StoredContract)
      })
    ,

    'TransferContract' : _reflection.GeneratedProtocolMessageType('TransferContract', (_message.Message,), {
      'DESCRIPTOR' : _DEPLOY_CODE_TRANSFERCONTRACT,
      '__module__' : 'consensus_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Code.TransferContract)
      })
    ,
    'DESCRIPTOR' : _DEPLOY_CODE,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Code)
    })
  ,

  'Arg' : _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOY_ARG,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.Arg)
    })
  ,

  'LegacyArg' : _reflection.GeneratedProtocolMessageType('LegacyArg', (_message.Message,), {

    'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
      'DESCRIPTOR' : _DEPLOY_LEGACYARG_VALUE,
      '__module__' : 'consensus_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.LegacyArg.Value)
      })
    ,
    'DESCRIPTOR' : _DEPLOY_LEGACYARG,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy.LegacyArg)
    })
  ,
  'DESCRIPTOR' : _DEPLOY,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Deploy)
  })
_sym_db.RegisterMessage(Deploy)
_sym_db.RegisterMessage(Deploy.Header)
_sym_db.RegisterMessage(Deploy.Body)
_sym_db.RegisterMessage(Deploy.Code)
_sym_db.RegisterMessage(Deploy.Code.WasmContract)
_sym_db.RegisterMessage(Deploy.Code.StoredVersionedContract)
_sym_db.RegisterMessage(Deploy.Code.StoredContract)
_sym_db.RegisterMessage(Deploy.Code.TransferContract)
_sym_db.RegisterMessage(Deploy.Arg)
_sym_db.RegisterMessage(Deploy.LegacyArg)
_sym_db.RegisterMessage(Deploy.LegacyArg.Value)

DeploySummary = _reflection.GeneratedProtocolMessageType('DeploySummary', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYSUMMARY,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.DeploySummary)
  })
_sym_db.RegisterMessage(DeploySummary)

BlockSummary = _reflection.GeneratedProtocolMessageType('BlockSummary', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSUMMARY,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.BlockSummary)
  })
_sym_db.RegisterMessage(BlockSummary)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_HEADER,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block.Header)
    })
  ,

  'Body' : _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_BODY,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block.Body)
    })
  ,

  'Justification' : _reflection.GeneratedProtocolMessageType('Justification', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_JUSTIFICATION,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block.Justification)
    })
  ,

  'ProcessedDeploy' : _reflection.GeneratedProtocolMessageType('ProcessedDeploy', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_PROCESSEDDEPLOY,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block.ProcessedDeploy)
    })
  ,

  'GlobalState' : _reflection.GeneratedProtocolMessageType('GlobalState', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_GLOBALSTATE,
    '__module__' : 'consensus_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block.GlobalState)
    })
  ,
  'DESCRIPTOR' : _BLOCK,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Block)
  })
_sym_db.RegisterMessage(Block)
_sym_db.RegisterMessage(Block.Header)
_sym_db.RegisterMessage(Block.Body)
_sym_db.RegisterMessage(Block.Justification)
_sym_db.RegisterMessage(Block.ProcessedDeploy)
_sym_db.RegisterMessage(Block.GlobalState)

Bond = _reflection.GeneratedProtocolMessageType('Bond', (_message.Message,), {
  'DESCRIPTOR' : _BOND,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Bond)
  })
_sym_db.RegisterMessage(Bond)

GenesisCandidate = _reflection.GeneratedProtocolMessageType('GenesisCandidate', (_message.Message,), {
  'DESCRIPTOR' : _GENESISCANDIDATE,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.GenesisCandidate)
  })
_sym_db.RegisterMessage(GenesisCandidate)

Era = _reflection.GeneratedProtocolMessageType('Era', (_message.Message,), {
  'DESCRIPTOR' : _ERA,
  '__module__' : 'consensus_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.Era)
  })
_sym_db.RegisterMessage(Era)


# @@protoc_insertion_point(module_scope)
